% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_imagem.R
\name{image_binary}
\alias{image_binary}
\title{Creates a binary image}
\usage{
image_binary(
  img,
  index = NULL,
  threshold = c("Otsu", "adaptive"),
  k = 0.1,
  windowsize = NULL,
  has_white_bg = FALSE,
  resize = FALSE,
  fill_hull = FALSE,
  filter = FALSE,
  re = NULL,
  nir = NULL,
  invert = FALSE,
  plot = TRUE,
  nrow = NULL,
  ncol = NULL,
  parallel = FALSE,
  workers = NULL,
  verbose = TRUE
)
}
\arguments{
\item{img}{An image object.}

\item{index}{A character value (or a vector of characters) specifying the
target mode for conversion to binary image. See the available indexes with
\code{\link[=pliman_indexes]{pliman_indexes()}} and \code{\link[=image_index]{image_index()}} for more details.}

\item{threshold}{The theshold method to be used.
\itemize{
\item By default (\code{threshold = "Otsu"}), a threshold value based
on Otsu's method is used to reduce the grayscale image to a binary image. If
a numeric value is informed, this value will be used as a threshold.
\item If \code{threshold = "adaptive"}, adaptive thresholding (Shafait et al. 2008)
is used, and will depend on the \code{k} and \code{windowsize} arguments.
\item If any non-numeric value different than \code{"Otsu"} and \code{"adaptive"} is used,
an iterative section will allow you to choose the threshold based on a
raster plot showing pixel intensity of the index.
}}

\item{k}{a numeric in the range 0-1. when \code{k} is high, local threshold
values tend to be lower. when \code{k} is low, local threshold value tend to be
higher.}

\item{windowsize}{windowsize controls the number of local neighborhood in
adaptive thresholding. By default it is set to \code{1/3 * minxy}, where
\code{minxy} is the minimum dimension of the image (in pixels).}

\item{has_white_bg}{Logical indicating whether a white background is present.
If \code{TRUE}, pixels that have R, G, and B values equals to 1 will be
considered as \code{NA}. This may be useful to compute an image index for
objects that have, for example, a white background. In such cases, the
background will not be considered for the threshold computation.}

\item{resize}{Resize the image before processing? Defaults to \code{FALSE}. Use a
numeric value as the percentage of desired resizing. For example, if
\code{resize = 30}, the resized image will have 30\% of the size of original
image.}

\item{fill_hull}{Fill holes in the objects? Defaults to \code{FALSE}.}

\item{filter}{Performs median filtering in the binary image? (Defaults to
\code{FALSE}). Provide a positive integer > 1 to indicate the size of the median
filtering. Higher values are more efficient to remove noise in the
background but can dramatically impact the perimeter of objects, mainly for
irregular perimeters such as leaves with serrated edges.}

\item{re}{Respective position of the red-edge band at the original image
file.}

\item{nir}{Respective position of the near-infrared band at the original
image file.}

\item{invert}{Inverts the binary image, if desired.}

\item{plot}{Show image after processing?}

\item{nrow, ncol}{The number of rows or columns in the plot grid. Defaults to
\code{NULL}, i.e., a square grid is produced.}

\item{parallel}{Processes the images asynchronously (in parallel) in separate
R sessions running in the background on the same machine. It may speed up
the processing time when \code{image} is a list. The number of sections is set
up to 70\% of available cores.}

\item{workers}{A positive numeric scalar or a function specifying the maximum
number of parallel processes that can be active at the same time.}

\item{verbose}{If \code{TRUE} (default) a summary is shown in the console.}
}
\value{
A list containing binary images. The length will depend on the number
of indexes used.
}
\description{
Reduce a color, color near-infrared, or grayscale images to a binary image
using a given color channel (red, green blue) or even color indexes. The
Otsu's thresholding method (Otsu, 1979) is used to automatically perform
clustering-based image thresholding.
}
\examples{
library(pliman)
img <- image_pliman("soybean_touch.jpg")
image_binary(img, index = c("R, G"))

}
\references{
Otsu, N. 1979. Threshold selection method from gray-level histograms. IEEE
Trans Syst Man Cybern SMC-9(1): 62–66. \doi{10.1109/tsmc.1979.4310076}

Shafait, F., D. Keysers, and T.M. Breuel. 2008. Efficient implementation of
local adaptive thresholding techniques using integral images. Document
Recognition and Retrieval XV. SPIE. p. 317–322 \doi{10.1117/12.767755}
}
\author{
Tiago Olivoto \email{tiagoolivoto@gmail.com}
}
